pub enum SkillAction {
Install,
Uninstall,
Update,
Status,
}Variants
Install
Install the worktree-manager agent skill into your coding agent
Uninstall
Remove the installed worktree-manager agent skill
Update
Update the installed skill to match the version bundled with this binary
Status
Show whether the skill is installed and if an update is available