extract_path_from_selection

Function extract_path_from_selection 

pub fn extract_path_from_selection(selection: &str) -> Result<PathBuf>
Helper function to parse path from selection string formatted as “repo/branch (path)”

Errors

Returns an error if the selection string is not in the expected format